<?php

namespace App\Http\Controllers\Admin;

use App\Models\Course;
use App\Models\Category;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Helper\fileManagerHelper;
use App\Http\Controllers\Controller;
use App\Http\Requests\CategoryRequest;
use Illuminate\Support\Facades\Storage;

class CategoryController extends Controller
{
    function __construct()
    {
        $this->middleware('permission:category-list', ['only' => ['index']]);
        $this->middleware('permission:category-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:category-edit', ['only' => ['edit', 'update']]);
        $this->middleware('permission:category-delete', ['only' => ['destroy']]);
    }

    public function index()
    {
        $categories = Category::whereParentId(null)->get();
        return view('admin.categories.index', compact('categories'));
    }

    public function get_categories()
    {
        $categories = Category::where('parent_id',  null)
            ->with('nodes')
            ->get();
        // $categories = collect($categories)->map(function ($item, $key) {
        //     if (count($item->nodes) > 0) {
        //         $item['nodes'] = $item->nodes;
        //     } else {
        //         $item['nodes'] = null;
        //     }
        //     return $item;
        // });
        return response()->json(['categories' => $categories], 200);
    }

    public function create($id = null)
    {
        $categories = Category::get();
        if (!is_null($id)) {
            return view('admin.categories.create', compact('categories', 'id'));
        }
        return view('admin.categories.create', compact('categories'));
    }

    public function store(CategoryRequest $request)
    {
        // return $request->all();
        try {

            $result = fileManagerHelper::storefile($request->image, 'categories');
            if ($result['code'] == 500)
                return redirect()->route("admin.categories.create")->with(['message' => $result['message'], 'type' => 'danger']);

            // __('admin.upload file error')
            $data = [
                'name' => ["en" => $request->name_en, "ar" => $request->name_ar],
                'status' => $request->status ? 'active' : 'disabled',
                'slug' => ["en" => Str::slug($request->name_en), "ar" => Str::slug($request->name_ar)],
                'parent_id' => $request->parent_id != null ? $request->parent_id : null,
                'image' => $result['filename'],
            ];

            Category::create($data);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }
        return redirect()->route('admin.categories.index')->with(['message' => __("admin.Has updated successfully"), 'type' => 'success']);
    }

    public function edit($id)
    {
        $category = Category::find($id);
        if (!$category) {
            return redirect()->back()->with(['error' => __("admin.Item not exist"), 'type' => 'danger']);
        }
        // return $category;
        return view('admin.categories.edit', compact('category'));
    }

    public function update(CategoryRequest $request, $id)
    {
        $category = Category::find($id);
        if (!$category) {
            return redirect()->back()->with(['error' => __("admin.Item not exist"), 'type' => 'danger']);
        }

        try {

            $data = [
                'name' => ["en" => $request->name_en, "ar" => $request->name_ar],
                'status' => $request->status ? 'active' : 'disabled',
                'slug' => ["en" => Str::slug($request->name_en), "ar" => Str::slug($request->name_ar)],
            ];

            if ($request->hasFile('image')) {
                if (isset($category->image) && Storage::exists($category->image)) {
                    Storage::delete($category->image);
                }
                $result = fileManagerHelper::storefile($request->image, 'categories');

                if ($result['code'] == 500)
                    return redirect()->route("admin.categories.create")->with(['message' => __('admin.upload file error'),  'type' => 'danger']);

                $data['image'] = $result['filename'];
            }

            $category->update($data);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }
        return redirect()->route('admin.categories.index')->with(['message' => __("admin.Has created successfully"), 'type' => 'success']);
    }

    public function destroy($id)
    {
        $category = Category::find($id);
        // return 1;
        if (!$category) {
            return response()->json(['message' => __("admin.Item not exist"), 'type' => 'danger'], 500);
        }

        try {

            $course = Course::where('category_id', $id)->count();
            if ($course > 0)
                return redirect()->route('admin.categories.index')->with(['message' => __("admin.cant delete category because have course"), 'type' => 'danger'], 500);

            if (isset($category->image) && Storage::exists($category->image)) {
                Storage::delete($category->image);
            }

            $category->delete();
        } catch (\Exception $ex) {
            return redirect()->route('admin.categories.index')->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger'], 500);
        }
        return redirect()->route('admin.categories.index')->with(['message' => __("admin.Has deleted successfully"), 'type' => 'success'], 200);
    }
}
