<?php

namespace App\Http\Controllers\Admin;

use App\Models\Guallery;
use Illuminate\Http\Request;
use App\Helper\fileManagerHelper;
use App\Http\Requests\ImageRequest;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class GualleryController extends Controller
{
    function __construct()
    {
        $this->middleware('permission:guallery-list', ['only' => ['index']]);
        $this->middleware('permission:guallery-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:guallery-edit', ['only' => ['edit', 'update']]);
        $this->middleware('permission:guallery-delete', ['only' => ['destroy']]);
    }

    public function index()
    {
        $gualleries = Guallery::get();
        return view('admin.gualleries.index', compact('gualleries'));
    }

    public function create()
    {
        return view('admin.gualleries.create');
    }

    public function store(ImageRequest $request)
    {
        try {
            $result = fileManagerHelper::storefile($request->file, 'gualleries');

            if ($result['code'] == 500)
                return redirect()->route("admin.guallery.create")->with(['message' => __('admin.upload file error'), 'type' => 'danger']);

            Guallery::create(['image' => $result['filename']]);
        } catch (\Exception $ex) {
            Storage::delete('public/gualleries/' . $result['filename']);
            return response()->json(['message' => __('admin.error_message'), 'error' => $ex->getMessage()], 500);
        }
        return response()->json(['uploaded' => '/gualleries/' . $result['filename']], 200);
    }

    public function destroy($id)
    {
        $gallery = Guallery::find($id);
        if (!$gallery) {
            return redirect()->route('admin.gualleries.index')->with(['message' => __("admin.Item not exist"), 'type' => 'danger']);
        }

        if (Storage::disk('public')->exists('gualleries/' . $gallery->image)) {
            Storage::delete('public/gualleries/' . $gallery->image);
        }
        $gallery->delete();
        return redirect()->route('admin.gualleries.index')->with(['message' => __("admin.Has deleted successfully"), 'type' => 'success']);
    }
}
