<?php

namespace App\Http\Controllers\Admin;

use App\Models\Product;
use App\Models\ProductImage;
use Illuminate\Http\Request;
use App\Helper\fileManagerHelper;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;
use App\Http\Requests\ProductImageRequest;

class ProductImageController extends Controller
{
    function __construct()
    {
        // $this->middleware('permission:product-index', ['only' => ['index']]);
        $this->middleware('permission:product-create', ['only' => ['store']]);
        // $this->middleware('permission:product-update', ['only' => ['update']]);
        $this->middleware('permission:product-delete', ['only' => ['destroy']]);
    }

    public function store(ProductImageRequest $request)
    {
        $product = Product::find($request->product_id);
        // $product = Product::find(1);
        if (!$product)
            return response()->json(['message' => __("admin.Item not exist"), 'type' => 'danger'], 500);

        try {

            $result = fileManagerHelper::storeFileWithID($request->file, 'product_images', $product->id);
            if ($result['code'] == 500)
                return response()->json(['message' => __('admin.upload file error'), 'type' => 'danger'], 500);

            $image = ProductImage::create([
                'product_id' => $product->id,
                'path' => $result['filename'],
            ]);
        } catch (\Exception $ex) {
            return response()->json(['message' => __("admin.error_message"), 'error' => $ex->getMessage(), 'type' => 'danger'], 500);
        }
        return response()->json(['message' => __("admin.Has created successfully"), 'type' => 'success', 'data' => $image->id]);
    }

    public function destroy($id)
    {
        // $product = Product::find($request->product_id);
        $img = ProductImage::find($id);
        if (!$img)
            return response()->json(['message' => __("admin.Item not exist"), 'type' => 'danger'], 500);

        try {

            if (Storage::disk('public')->exists($img->path)) {
                Storage::delete('public/' . $img->path);
            }
            $img->delete();
        } catch (\Exception $ex) {
            return response()->json(['message' => __("admin.error_message"), 'error' => $ex->getMessage(), 'type' => 'danger'], 500);
        }
        return response()->json(['message' => __("admin.Has deleted successfully"), 'type' => 'success']);
    }
}
