<?php

namespace App\Http\Controllers\Admin;

use App\Models\Slider;
use Illuminate\Support\Facades\Storage;
use Illuminate\Http\Request;
use App\Helper\fileManagerHelper;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Str;
use App\Http\Requests\SliderRequest;

class SliderController extends Controller
{
    public function index()
    {
        $sliders = Slider::get();
        return view('admin.sliders.index')->with('sliders', $sliders);
    }


    public function create()
    {
        return view('admin.sliders.create');
    }


    public function store(SliderRequest $request)
    {
        // return $request->all();
        $result = fileManagerHelper::storefile($request->image, 'sliders');
        if ($result['code'] == 500)
            return redirect()->route("admin.sliders.create")->with(['message' => __('admin.upload file error'), 'type' => 'danger']);

        try {
            Slider::create([
                'title' => ["en" => $request->title_en, "ar" => $request->title_ar],
                'descreption' => ["en" => $request->content_en, "ar" => $request->content_ar],
                'image' => $result['filename'],
            ]);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.sliders.index")->with(['message' => __('admin.Has created successfully'), 'type' => 'success']);
    }


    public function edit($id)
    {
        $slider = Slider::find($id);

        if (!$slider) {
            return redirect()->route("admin.sliders.index")->with(['message' => __('admin.Slider not exist'), 'type' => 'danger']);
        }

        return view('admin.sliders.edit')->with('slider', $slider);
    }

    public function update(SliderRequest $request)
    {
        $slider = Slider::find($request->id);

        if (!$slider)
            return redirect()->route("admin.sliders.index")->with(['message' => __('admin.Slider not exist'), 'type' => 'danger']);

        $data = [
            'title' => ["en" => $request->title_en, "ar" => $request->title_ar],
            'descreption' => ["en" => $request->content_en, "ar" => $request->content_ar],
        ];

        if ($request->hasFile('image')) {
            if (isset($slider->image) && Storage::exists($slider->image)) {
                Storage::delete($slider->image);
            }
            $result = fileManagerHelper::storefile($request->image, 'sliders');

            if ($result['code'] == 500)
                return redirect()->route("admin.sliders.create")->with(['message' => __('admin.upload file error'),  'type' => 'danger']);

            $data['image'] = $result['filename'];
        }

        try {
            $slider->update($data);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.sliders.index")->with(['message' => __('admin.Has updated successfully'),  'type' => 'success']);
    }

    public function destroy($id)
    {
        $slider = Slider::find($id);

        if (!$slider) {
            return redirect()->route("admin.sliders.index")->with(['message' => __('admin.Slider not exist'),  'type' => 'danger']);
        }

        if (isset($slider->image) && Storage::exists($slider->image)) {
            Storage::delete($slider->image);
        }

        $slider->delete();

        return redirect()->route("admin.sliders.index")->with(['message' => __('admin.Has deleted successfully'), 'type' => 'success']);
    }
}
