<?php

namespace App\Http\Controllers\Admin;

use App\Models\User;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Requests\StudentRequest;
use Illuminate\Support\Facades\Hash;

class StudentController extends Controller
{
    function __construct()
    {
        $this->middleware('permission:student-list', ['only' => ['index']]);
        $this->middleware('permission:student-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:student-edit', ['only' => ['edit', 'update']]);
        $this->middleware('permission:student-delete', ['only' => ['destroy']]);
    }

    public function index()
    {
        $students = User::whereType('student')->get();
        return view('admin.students.index')->with('students', $students);
    }

    public function create()
    {
        return view('admin.students.create');
    }


    public function store(StudentRequest $request)
    {
        // return $request->all();
        try {
            User::create([
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'address' => $request->address,
                'country' => $request->country,
                'city' => $request->city,
                'phone' => $request->phone,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'type' => 'student'
            ]);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.students.index")->with(['message' => __('admin.Has created successfully'), 'type' => 'success']);
    }

    public function edit($id)
    {
        $student = User::whereId($id)->whereType('student')->first();

        if (!$student) {
            return redirect()->route("admin.students.index")->with(['message' => __('admin.Team not exist'), 'type' => 'danger']);
        }

        return view('admin.students.edit')->with('student', $student);
    }

    public function update(StudentRequest $request, $id)
    {

        $student = User::whereId($id)->whereType('student')->first();

        if (!$student) {
            return redirect()->route("admin.students.index")->with(['message' => __('admin.Team not exist'), 'type' => 'danger']);
        }

        try {
            $student->update([
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'address' => $request->address,
                'country' => $request->country,
                'city' => $request->city,
                'phone' => $request->phone,
            ]);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.students.index")->with(['message' => __('admin.Has created successfully'), 'type' => 'success']);
    }

    public function destroy($id)
    {
        $student = User::whereId($id)->whereType('student')->first();

        if (!$student) {
            return redirect()->route("admin.students.index")->with(['message' => __('admin.Team not exist'),  'type' => 'danger']);
        }

        $student->update(['status' => 'disabled']);

        return redirect()->route("admin.students.index")->with(['message' => __('admin.Has deleted successfully'), 'type' => 'success']);
    }

    public function change_status(Request $request, $id)
    {
        $course = User::find($id);
        if (!$course) {
            return response()->json(['message' => __("admin.Item not exist"), 'type' => 'danger']);
        }
        try {
            $status = $request->has('status') && $request->status == 'active' ? 'active' : 'disabled';
            $data = [
                'status' => $status,
            ];
            $course->update($data);
        } catch (\Exception $ex) {
            return response()->json(['message' => __("admin.error_message"), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }
        return response()->json(['message' => __("admin.Has updated successfully"), 'type' => 'success']);
    }

    public function get_courses($id)
    {
        $user = User::with('courses_student')->whereId($id)->whereType('student')->first();
        if (!$user) {
            return redirect()->route("admin.students.index")->with(['message' => __('admin.Team not exist'),  'type' => 'danger']);
        }

        return view('admin.students.courses')->with('user', $user);
    }
}
