<?php

namespace App\Http\Controllers\Admin;

use App\Models\Team;
use Illuminate\Support\Facades\Storage;
use Illuminate\Http\Request;
use App\Helper\fileManagerHelper;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Str;
use App\Http\Requests\TeamRequest;

class TeamController extends Controller
{
    public function index()
    {
        $teams = Team::get();
        return view('admin.teams.index')->with('teams', $teams);
    }


    public function create()
    {
        return view('admin.teams.create');
    }


    public function store(TeamRequest $request)
    {
        // return $request->all();
        $result = fileManagerHelper::storefile($request->image, 'teams');
        if ($result['code'] == 500)
            return redirect()->route("admin.teams.create")->with(['message' => __('admin.upload file error'), 'type' => 'danger']);

        try {
            Team::create([
                'title' => $request->name,
                // 'title' => ["en" => $request->title_en, "ar" => $request->title_ar],
                'descreption' => ["en" => $request->desc_en, "ar" => $request->desc_ar],
                'image' => $result['filename'],
            ]);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.teams.index")->with(['message' => __('admin.Has created successfully'), 'type' => 'success']);
    }


    public function edit($id)
    {
        $team = Team::find($id);

        if (!$team) {
            return redirect()->route("admin.teams.index")->with(['message' => __('admin.Team not exist'), 'type' => 'danger']);
        }

        return view('admin.teams.edit')->with('team', $team);
    }

    public function update(TeamRequest $request)
    {
        $team = Team::find($request->id);

        if (!$team)
            return redirect()->route("admin.teams.index")->with(['message' => __('admin.Team not exist'), 'type' => 'danger']);

        $data = [
            // 'title' => ["en" => $request->title_en, "ar" => $request->title_ar],
            'title' => $request->name,
            'descreption' => ["en" => $request->desc_en, "ar" => $request->desc_ar],
        ];

        if ($request->hasFile('image')) {
            if (isset($team->image) && Storage::exists($team->image)) {
                Storage::delete($team->image);
            }
            $result = fileManagerHelper::storefile($request->image, 'teams');

            if ($result['code'] == 500)
                return redirect()->route("admin.teams.create")->with(['message' => __('admin.upload file error'),  'type' => 'danger']);

            $data['image'] = $result['filename'];
        }

        try {
            $team->update($data);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.teams.index")->with(['message' => __('admin.Has updated successfully'),  'type' => 'success']);
    }

    public function destroy($id)
    {
        $team = Team::find($id);

        if (!$team) {
            return redirect()->route("admin.teams.index")->with(['message' => __('admin.Team not exist'),  'type' => 'danger']);
        }

        if (isset($team->image) && Storage::exists($team->image)) {
            Storage::delete($team->image);
        }

        $team->delete();

        return redirect()->route("admin.teams.index")->with(['message' => __('admin.Has deleted successfully'), 'type' => 'success']);
    }
}
