<?php


namespace App\Http\Controllers\Admin;

use App\Models\User;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Requests\StudentRequest;
use Illuminate\Support\Facades\Hash;

class TutorController extends Controller
{
    function __construct()
    {
        $this->middleware('permission:tutor-list', ['only' => ['index']]);
        $this->middleware('permission:tutor-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:tutor-edit', ['only' => ['edit', 'update']]);
        $this->middleware('permission:tutor-delete', ['only' => ['destroy']]);
    }

    public function index()
    {
        $tutors = User::whereType('tutor')->get();
        return view('admin.tutors.index')->with('tutors', $tutors);
    }

    public function create()
    {
        return view('admin.tutors.create');
    }


    public function store(StudentRequest $request)
    {
        try {
            User::create([
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'address' => $request->address,
                'country' => $request->country,
                'city' => $request->city,
                'phone' => $request->phone,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'type' => 'tutor'
            ]);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Has created successfully'), 'type' => 'success']);
    }

    public function edit($id)
    {
        $tutor = User::whereId($id)->whereType('tutor')->first();

        if (!$tutor) {
            return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Team not exist'), 'type' => 'danger']);
        }

        return view('admin.tutors.edit')->with('tutor', $tutor);
    }

    public function update(StudentRequest $request, $id)
    {

        $tutor = User::whereId($id)->whereType('tutor')->first();

        if (!$tutor) {
            return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Team not exist'), 'type' => 'danger']);
        }

        try {
            $tutor->update([
                'first_name' => $request->first_name,
                'last_name' => $request->last_name,
                'address' => $request->address,
                'country' => $request->country,
                'city' => $request->city,
                'phone' => $request->phone,
            ]);
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }

        return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Has created successfully'), 'type' => 'success']);
    }

    public function destroy($id)
    {
        $tutor = User::whereId($id)->whereType('tutor')->first();

        if (!$tutor) {
            return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Team not exist'),  'type' => 'danger']);
        }

        $tutor->update(['status' => 'disabled']);

        return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Has deleted successfully'), 'type' => 'success']);
    }

    public function change_status(Request $request, $id)
    {
        $user = User::whereId($id)->whereType('tutor')->first();
        if (!$user) {
            return response()->json(['message' => __("admin.Item not exist"), 'type' => 'danger']);
        }
        try {
            $status = $request->has('status') && $request->status == 'active' ? 'active' : 'disabled';
            $data = [
                'status' => $status,
            ];
            $user->update($data);
        } catch (\Exception $ex) {
            return response()->json(['message' => __("admin.error_message"), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }
        return response()->json(['message' => __("admin.Has updated successfully"), 'type' => 'success']);
    }

    public function get_courses($id)
    {
        $user = User::with('courses_tutor')->whereId($id)->whereType('tutor')->first();
        if (!$user) {
            return redirect()->route("admin.tutors.index")->with(['message' => __('admin.Team not exist'),  'type' => 'danger']);
        }

        return view('admin.tutors.courses')->with('user', $user);
    }
}
