<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use App\Models\CartDetail;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class CartController extends Controller
{
    public function index()
    {
        $cart = Cart::with('details.product')->where('user_id', Auth::user()->id)->first();
        return view('site.cart', compact('cart'));
    }

    public function getCountCart()
    {
        $count = Cart::where('user_id', Auth::user()->id)->value('total_count');
        return response()->json(['data' => $count]);
    }
    public function store(Request $request)
    {
        // return $request->all();
        try {


            $cart = Cart::where('user_id', Auth::user()->id)->first();
            if (!$cart)
                $cart = Cart::create([
                    'user_id' => Auth::user()->id,
                ]);

            $products = $request->product;
            $result = null;
            // return $products = count($request->product);
            foreach ($products as $product) {
                $check_exsit_product = CartDetail::where('cart_id', $cart->id)->where('product_id', $product['product_id'])->first();
                if (!$check_exsit_product) {
                    $result = CartDetail::create(
                        [
                            'cart_id' => $cart->id,
                            'product_id' => $product['product_id'],
                            'quantity' => $product['quantity']
                        ]
                    );
                } else {
                    $check_exsit_product->update(['quantity' => $product['quantity']]);
                }
            }

            $total_count = CartDetail::where('cart_id', $cart->id)->sum('quantity');
            $cart->update(['total_count' => $total_count]);
            DB::commit();
            return response()->json(['message' => __('site.the cart details has been updated'), 'data' => $result, 'cart' => $cart]);
        } catch (\Exception $e) {
            DB::rollback();
            return  response()->json(['message' => $e->getMessage()], 500);
        }
    }

    public function clear()
    {
        $cart = Cart::where('user_id', Auth::user()->id)->first();
        if (!$cart)
            return redirect()->route("site.cart")->with(['message' => __('site.there is no cart'), 'type' => 'danger']);

        $cart->delete();
        return redirect()->route("site.cart")->with(['message' => __('site.has cleaed cart'), 'type' => 'success']);
    }

    public function update(Request $request)
    {
        // return $request->all();
        $cart = Cart::where('user_id', Auth::user()->id)->first();
        if (!$cart)
            return redirect()->route("site.cart")->with(['message' => __('site.there is no cart'), 'type' => 'danger']);

        try {
            for ($i = 0; $i < count($request->id); $i++) {
                $product = CartDetail::find($request->id[$i]);
                if ($product)
                    $product->update(['quantity' => $request->quantity[$i]]);
            }
            $total_count = CartDetail::where('cart_id', $cart->id)->sum('quantity');
            $cart->update(['total_count' => $total_count]);
            return redirect()->route("site.cart")->with(['message' => __('site.has been updated cart'), 'type' => 'success']);
        } catch (\Exception $ex) {
            return redirect()->route("site.cart")->with(['message' => __('admin.error_message'), '  error' => $ex->getMessage(), 'type' => 'danger']);
        }
    }

    public function  destroy($id)
    {
        $product = CartDetail::find($id);
        if (!$product)
            return response()->json(['message' => __('site.Item not exist'), 'type' => 'danger']);

        try {
            Cart::whereId($product->cart_id)->update(['total_count' => DB::raw(DB::raw('(select total_count from carts where id =' . $product->cart_id) . ') - ' . $product->quantity)]);
            $product->delete();
            return response()->json(['message' => __('site.has been deleted cart'), 'type' => 'success', 'data' => Cart::where('user_id', Auth::user()->id)->value('total_count')]);
        } catch (\Exception $ex) {
            return response()->json(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger'], 500);
        }
    }
}
