<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use App\Models\Order;
use App\Models\Product;
use App\Models\CartDetail;
use App\Models\OrderDetails;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class OrderController extends Controller
{
    public function index()
    {
        $orders = Order::get();
        return view('admin.orders.index', compact('orders'));
    }

    public function details($id)
    {
        $order = Order::find($id);
        if (!$order)
            return redirect()->route('admin.orders.index')->with(['message' => 'the order has been created', 'type' => 'error']);

        $details = OrderDetails::with('Product')->where('order_id', $id)->get();
        return view('admin.orders.details', compact('details'));
    }
    public function store(Request $request)
    {
        DB::beginTransaction();
        try {
            $cart = Cart::with('details.product')->where('user_id', Auth::user()->id)->first();
            $ids_products = CartDetail::pluck('product_id')->toArray();
            $all_price = Product::whereIn('id', $ids_products)->sum('price');
            $user = Auth::user();
            $order = Order::create([
                'address' => $request->address ? $request->address : $user->address,
                'total_price' => $all_price,
                'total_count' => $cart->total_count,
                'city' => $request->city ? $request->city : $user->city,
                'country' => $request->country ? $request->country : $user->country,
                'status' => 'pending',
            ]);

            $insert_data = [];
            foreach ($cart->details as $item) {
                array_push($insert_data, [
                    'quantity' => $item->quantity,
                    'total_price' => Product::where('id', $item->product_id)->value('price') * $item->quantity,
                    'product_id' => $item->product_id,
                    'order_id' => $order->id
                ]);
            }

            OrderDetails::insert($insert_data);
            Cart::where('user_id', Auth::user()->id)->delete();
            DB::commit();
            return redirect()->route('site.order')->with(['message' => 'the order has been created']);
        } catch (\Exception $e) {
            DB::rollBack();
            return redirect()->route('site.order')->with(['message' => 'there is error', 'error' => $e->getMessage()]);
        }
    }
}
