<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use App\Helper\fileManagerHelper;
use App\Http\Requests\AvatarRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Redirect;
use App\Http\Requests\ProfileUpdateRequest;
use App\Models\Course;
use App\Models\StudentCourse;

class ProfileController extends Controller
{
    /**
     * Display the user's profile form.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\View\View
     */
    public function edit(Request $request)
    {
        return view('profile.edit', [
            'user' => $request->user(),
        ]);
    }

    /**
     * Update the user's profile information.
     *
     * @param  \App\Http\Requests\ProfileUpdateRequest  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update(ProfileUpdateRequest $request)
    {
        $request->user()->fill($request->validated());

        if ($request->user()->isDirty('email')) {
            $request->user()->email_verified_at = null;
        }

        $request->user()->save();

        return Redirect::route('profile.edit')->with('status', 'profile-updated');
    }

    /**
     * Delete the user's account.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy(Request $request)
    {
        $request->validateWithBag('userDeletion', [
            'password' => ['required', 'current-password'],
        ]);

        $user = $request->user();

        Auth::logout();

        $user->delete();

        $request->session()->invalidate();
        $request->session()->regenerateToken();

        return Redirect::to('/');
    }

    public function uploadAvatar(AvatarRequest $request)
    {
        $user = User::find(Auth::user()->id);
        if (!$user) {
            return response()->json(['message' => __('admin.this user dose not exist'), 'type' => 'danger'], 500);
        }
        try {
            $result = fileManagerHelper::storeFile($request->file, 'profile');
            if ($result['code'] == 500)
                return response()->json(['message' => __('admin.upload file error'), 'type' => 'danger'], 500);
            $user->update(['avatar' => $result['filename']]);
            return response()->json(['message' => __("admin.Has updated your image successfully"), 'type' => 'success']);
        } catch (\Exception $ex) {
            Storage::delete('public/profile/' . $result['filename']);
            return response()->json(['message' => __("admin.error_message"), 'error' => $ex->getMessage(), 'type' => 'danger'], 500);
        }
    }
    public function getMyCourses()
    {
        // return Auth::user()->type;
        $user = Auth::user();
        if ($user->type == 'student')
            $data = User::where('id', $user->id)->with('courses_student')->first();
        else
            $data = User::where('id', $user->id)->with('courses_tutor')->first();

        // return $data;
        return view('profile.my_course', compact('data'));
    }

    public function getstudentsByCourse($id)
    {
        // $lang = app()->getLocale();
        // $course = Course::with('Students')->where('slug->' . $lang, $slug)->first();
        $course = Course::with('Students')->find($id);

        if (!$course) {
            return response()->json(['message' => __('admin.Team not exist'),  'type' => 'danger'], 500);
        }

        return response()->json(['course' => $course]);
    }
}
