<?php

namespace App\Http\Controllers;

use Exception;
use App\Models\Cart;
use App\Models\Course;
use App\Models\Slider;
use App\Models\Contact;
use App\Models\Product;
use App\Models\Setting;
use App\Models\Category;
use App\Models\Guallery;
use App\Mail\ContactMail;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use App\Http\Requests\ContactRequest;
use App\Models\CartDetail;
use App\Models\StudentCourse;
use Illuminate\Support\Facades\Session;

class SiteController extends Controller
{
    public function index()
    {
        $sliders = Slider::get();

        // $courses = Course::whereShow(1)->whereStatus('open')->get();

        $categories_with_course  = Category::with(['Courses.Students' => function ($q) {
            if (Auth::check())
                return $q->where('student_courses.student_id', Auth::user()->id)->first();
        }])->whereParentId(null)->whereStatus('active')->get();

        $data = $this->navigateAndFooter();
        $setting = $data['setting'];
        $categories = $data['categories'];

        return view('site.index', compact('setting', 'sliders', 'categories', 'categories_with_course'));
    }

    public function coursesByCategory($slug)
    {
        $lang = app()->getLocale();
        $category = Category::where('slug->' . $lang, $slug)->first();

        if (!$category) {
            return redirect()->route("site.home")->with(['message' => __('site.category not exist'), 'type' => 'danger']);
        }

        $data = $this->navigateAndFooter();

        $courses = Course::where('category_id', $category->id)->get();

        $min_price = Course::select('price')->min('price');
        $max_price = Course::select('price')->max('price');

        $setting = $data['setting'];
        $categories = $data['categories'];

        return view('site.courses', compact('courses', 'setting', 'categories', 'min_price', 'max_price'));
    }

    public function registerCourse($id)
    {
        $course = Course::find($id);
        if (!$course)
            return response()->json(['message' => __('site.this course not exsit')], 500);

        StudentCourse::create(['course_id' => $course->id, 'student_id' => Auth::user()->id]);
        return response()->json(['message' => __('site.has been rejesterd')], 200);
    }

    public function getGualleries()
    {
        $gualleries = Guallery::get();
        return view('site.guallery', compact('gualleries'));
    }

    public function getContactUs()
    {
        $setting = Setting::all();
        return view('site.contact', compact('setting'));
    }
    public function contactUS(ContactRequest $request)
    {
        $data = [
            'name' => $request->name,
            'subject' => $request->subject,
            'email' => $request->email,
            'message' => $request->message,
        ];
        try {
            Contact::create($data);

            $tomail = Setting::where('name', 'email')->value('value');
            if ($tomail) {
                // Mail::to($tomail)
                //     ->send(new ContactMail($data));
            }
        } catch (\Exception $ex) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'error' => $ex->getMessage(), 'type' => 'danger']);
        }
        return redirect()->back()->with(['message' => __('site.done message'), 'type' => 'success']);
    }



    public function Store()
    {
        $products = Product::where('show', 1)->get();
        return view('site.store', compact('products'));
    }

    public function StoreDetails($slug)
    {
        $lang = app()->getLocale();
        $product = Product::with('Images')->where('slug->' . $lang, $slug)->first();
        if (!$product) {
            return redirect()->back()->with(['message' => __('admin.error_message'), 'type' => 'danger']);
        }
        // dd($product);
        return view('site.store_details', compact('product'));
    }

    private function navigateAndFooter()
    {
        $categories  = Category::whereParentId(null)->whereStatus('active')->get();

        $setting = Setting::all();
        return ['categories' => $categories, 'setting' => $setting,];
    }

    public function change_lang_site($name)
    {
        $old_lang = Session::get('locale');

        if ($name == "ar") {
            Session::put('direction', 'rtl');
            $lang = "ar";
        } else {
            Session::put('direction', 'ltr');
            $lang = "en";
        }
        $currentURL = Str::after(url()->previous(), '' . $old_lang . '');
        return redirect('/' . $lang . $currentURL);
    }

    public function searchCourse(Request $request)
    {
        // return $request->all();
        // DB::enableQueryLog();
        try {
            $result = Course::with('Category');
            if ($request->category != 'all' && $request->category != '') {
                $result->where('category_id', $request->category);
            }
            if ($request->date != '') {
                $result->whereDate('start_date', '>=', $request->date);
            }
            $min = ($request->min_price != '') ? $request->min_price : 0;
            $max = ($request->max_price != '') ? $request->max_price : Course::max('price');
            $result->whereBetween('price', [$min, $max]);
            $data = $result->get();
            return response()->json(['data' => $data]);
        } catch (\Exception $ex) {
            return response()->json(['message' => __('admin.somthing wrong'), 'error' => $ex->getMessage()], 500);
        }

        // return view('site.store', compact('products'));
    }

    public function search(Request $request)
    {
        // $lang = app()->getLocale();
        $course = array();
        $category = array();
        // if ($request->search_term) {
        //     $course = Course::where(function ($q) use ($request) {
        //         $q->where('name->ar', 'like', '%' . $request->search_term . '%')
        //             ->orWhere('name->en', 'like', '%' . $request->search_term . '%');
        //     })->get();
        // }

        // if ($request->search_term) {
        //     $category = Category::where(function ($q) use ($request) {
        //         $q->where('name->ar', 'like', '%' . $request->search_term . '%')->orWhere('name->en', 'like', '%' . $request->search_term . '%');
        //     })->get();
        // }

        $data = array_merge($course, $category);
        return response()->json(['data' => $data]);
    }

    public function getOrder()
    {
        $cart = Cart::with('details.product')->where('user_id', Auth::user()->id)->first();
        $user = Auth::user();
        $ids_products = CartDetail::pluck('product_id')->toArray();
        $all_price = Product::whereIn('id', $ids_products)->sum('price');
        return view('site.order', compact('cart', 'user', 'all_price'));
    }
}
