<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Spatie\Translatable\HasTranslations;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Course extends Model
{
    use HasFactory;


    use HasTranslations;

    public $translatable = ['name'];
    protected $appends = ['full_path', 'course'];
    protected $fillable = ['name', 'status', 'show', 'start_date', 'end_date', 'price', 'category_id', 'image'];

    public function getFullPathAttribute()
    {
        return $this->img();
    }

    public function getCourseAttribute()
    {
        return $this->name;
    }

    public function Category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function Students()
    {
        return $this->belongsToMany(User::class, 'student_courses', 'course_id', 'student_id');
    }

    public function Tutors()
    {
        return $this->belongsToMany(User::class, 'tutor_courses', 'course_id', 'tutor_id');
    }


    public function getStartDate()
    {
        return date('M d , Y', strtotime($this->start_date));
    }

    public function getEndDate()
    {
        return date('M d , Y', strtotime($this->end_date));
    }

    public function getShow()
    {
        return $this->show == 1 ? __('admin.yes') : __('admin.no');
    }

    public function getStatus()
    {
        return __('admin.' . $this->status);
    }

    public function getPathImage()
    {
        return $this->img();
    }

    public function img()
    {
        if (strpos($this->image, "http") != '')
            return $this->image;
        else
            return url('public/storage/' . $this->image);
    }
    // protected $casts = [
    //     'start_date' => 'date:D M, Y H',
    //     'end_date' => 'date:d M, Y H',
    // ];
}
