<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'email',
        'password',
        'first_name',
        'last_name',
        'country',
        'city',
        'address',
        'phone',
        'by_admin',
        'avatar',
        'status',
        'type'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    protected $appends = [
        'full_path',
        'username'
    ];
    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function getByAdmin()
    {
        return $this->by_admin == 1 ? __('admin.by admin') : __('admin.register');
    }

    public function courses_tutor()
    {
        return $this->belongsToMany(Course::class, 'tutor_courses', 'tutor_id', 'course_id');
    }

    public function courses_student()
    {
        return $this->belongsToMany(Course::class, 'student_courses', 'student_id', 'course_id');
    }

    public function getFullPathAttribute()
    {
        if ($this->avatar == null || $this->avatar == '')
            return asset('admin/images/placeholder.png');
        else
            return url('public/storage/' . $this->avatar);
    }
    public function getAvatar()
    {
        if ($this->avatar == null || $this->avatar == '')
            return asset('admin/images/placeholder.png');
        else
            return url('public/storage/' . $this->avatar);
    }
    public function getUserNameAttribute()
    {
        return $this->first_name . ' ' . $this->last_name;
    }
}
