<?php

use App\Http\Controllers\Admin\SliderController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\RoleController;
use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\CourseController;
use App\Http\Controllers\Admin\ProfileController;
use App\Http\Controllers\Admin\SettingController;
use App\Http\Controllers\Admin\GualleryController;
use App\Http\Controllers\Admin\StudentController;
use App\Http\Controllers\Admin\TeamController;
use App\Http\Controllers\Admin\TutorController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\ProductImageController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\OrderController;

Route::prefix('admin')->name('admin.')->group(function () {

    require __DIR__ . '/admin_auth.php';

    Route::middleware('auth:admin')->group(function () {

        Route::get('/dashboard', [DashboardController::class, 'index'])->name('dashboard');
        Route::post('/get-count-student-course', [DashboardController::class, 'getCountStudentCourse'])->name('count.student.course');

        Route::name('profile.')->prefix('profile')->group(function () {
            Route::get('/', [ProfileController::class, 'edit'])->name('edit');
            Route::patch('/', [ProfileController::class, 'update'])->name('update');
            Route::delete('/', [ProfileController::class, 'destroy'])->name('destroy');
        });

        Route::name('setting.')->prefix('setting')->group(function () {
            Route::get('/', [SettingController::class, 'index'])->name('index');
            Route::get('/{id}', [SettingController::class, 'edit'])->name('edit');
            Route::post('/{id}', [SettingController::class, 'update'])->name('update');
        });

        Route::name('roles.')->prefix('roles')->group(function () {
            Route::get('/', [RoleController::class, 'index'])->name('index');
            Route::get('/create', [RoleController::class, 'create'])->name('create');
            Route::post('/store', [RoleController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [RoleController::class, 'edit'])->name('edit');
            Route::patch('/update/{id}', [RoleController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [RoleController::class, 'destroy'])->name('destroy');
        });


        Route::name('users.')->prefix('users')->group(function () {
            Route::get('/', [UserController::class, 'index'])->name('index');
            Route::get('/create', [UserController::class, 'create'])->name('create');
            Route::post('/store', [UserController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [UserController::class, 'edit'])->name('edit');
            Route::patch('/update/{id}', [UserController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [UserController::class, 'destroy'])->name('destroy');
        });

        Route::name('categories.')->prefix('categories')->group(function () {
            Route::get('/', [CategoryController::class, 'index'])->name('index');
            Route::get('/get', [CategoryController::class, 'get_categories'])->name('get_categories');
            Route::get('/create/{id?}', [CategoryController::class, 'create'])->name('create');
            Route::post('/store', [CategoryController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [CategoryController::class, 'edit'])->name('edit');
            Route::patch('/update/{id}', [CategoryController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [CategoryController::class, 'destroy'])->name('destroy');
        });

        Route::name('courses.')->prefix('courses')->group(function () {
            Route::get('/', [CourseController::class, 'index'])->name('index');
            Route::get('/create', [CourseController::class, 'create'])->name('create');
            Route::post('/store', [CourseController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [CourseController::class, 'edit'])->name('edit');
            Route::post('/update/{id}', [CourseController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [CourseController::class, 'destroy'])->name('destroy');
            Route::post('/change_status/{id}', [CourseController::class, 'change_status'])->name('status');
            Route::post('/change_show/{id}', [CourseController::class, 'change_show'])->name('show');
            Route::get('/{id}/tutor', [CourseController::class, 'tutor'])->name('tutor');
        });

        Route::name('sliders.')->prefix('sliders')->group(function () {
            Route::get('/', [SliderController::class, 'index'])->name('index');
            Route::get('/create', [SliderController::class, 'create'])->name('create');
            Route::post('/store', [SliderController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [SliderController::class, 'edit'])->name('edit');
            Route::post('/update/{id}', [SliderController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [SliderController::class, 'destroy'])->name('destroy');
        });

        Route::name('teams.')->prefix('teams')->group(function () {
            Route::get('/', [TeamController::class, 'index'])->name('index');
            Route::get('/create', [TeamController::class, 'create'])->name('create');
            Route::post('/store', [TeamController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [TeamController::class, 'edit'])->name('edit');
            Route::post('/update/{id}', [TeamController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [TeamController::class, 'destroy'])->name('destroy');
        });

        Route::name('students.')->prefix('students')->group(function () {
            Route::get('/', [StudentController::class, 'index'])->name('index');
            Route::get('/create', [StudentController::class, 'create'])->name('create');
            Route::post('/store', [StudentController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [StudentController::class, 'edit'])->name('edit');
            Route::patch('/update/{id}', [StudentController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [StudentController::class, 'destroy'])->name('destroy');
            Route::post('/change_status/{id}', [StudentController::class, 'change_status'])->name('status');
            Route::get('/courses/{id}', [TutorController::class, 'get_courses'])->name('courses');
        });

        Route::name('tutors.')->prefix('tutors')->group(function () {
            Route::get('/', [TutorController::class, 'index'])->name('index');
            Route::get('/create', [TutorController::class, 'create'])->name('create');
            Route::post('/store', [TutorController::class, 'store'])->name('store');
            Route::get('/edit/{id}', [TutorController::class, 'edit'])->name('edit');
            Route::patch('/update/{id}', [TutorController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [TutorController::class, 'destroy'])->name('destroy');
            Route::post('/change_status/{id}', [TutorController::class, 'change_status'])->name('status');
            Route::get('/courses/{id}', [TutorController::class, 'get_courses'])->name('courses');
        });

        Route::name('products.')->prefix('products')->group(function () {
            Route::get('/', [ProductController::class, 'index'])->name('index');
            Route::get('/create', [ProductController::class, 'create'])->name('create');
            Route::post('/store', [ProductController::class, 'store'])->name('store');
            Route::post('/store/image', [ProductController::class, 'store_image'])->name('store.image');
            Route::get('/edit/{id}', [ProductController::class, 'edit'])->name('edit');
            Route::post('/update/{id}', [ProductController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [ProductController::class, 'destroy'])->name('destroy');
            Route::post('/change_status/{id}', [ProductController::class, 'change_status'])->name('status');
        });

        Route::name('product_images.')->prefix('product_images')->group(function () {
            Route::get('/', [ProductImageController::class, 'index'])->name('index');
            Route::post('/store', [ProductImageController::class, 'store'])->name('store');
            Route::patch('/update/{id}', [ProductImageController::class, 'update'])->name('update');
            Route::delete('/destroy/{id}', [ProductImageController::class, 'destroy'])->name('destroy');
        });

        Route::name('gualleries.')->prefix('gualleries')->group(function () {
            Route::get('/', [GualleryController::class, 'index'])->name('index');
            Route::get('/create', [GualleryController::class, 'create'])->name('create');
            Route::post('/store', [GualleryController::class, 'store'])->name('store');
            Route::delete('/destroy/{id}', [GualleryController::class, 'destroy'])->name('destroy');
        });

        Route::name('orders.')->prefix('orders')->group(function () {
            Route::get('/', [OrderController::class, 'index'])->name('index');
            Route::get('/details/{id}', [OrderController::class, 'details'])->name('details');
        });
    });
});
