<?php

use App\Http\Controllers\CartController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\SiteController;
use Illuminate\Support\Facades\Route;

Route::get('/', function () {
    return view('soon');
});
Route::group(
    [
        'prefix' => LaravelLocalization::setLocale(),
        'middleware' => ['localeSessionRedirect', 'localizationRedirect', 'localeViewPath', 'localSessionDirection']
    ],
    function () {
        // Route::get('/', function () {
        //     return view('soon');
        // });
        Route::get('/lang/{name}', [SiteController::class, 'change_lang_site'])->name('changelang');

        Route::get('/dashboard', function () {
            return view('dashboard');
        })->middleware(['auth', 'verified'])->name('dashboard');


        Route::middleware('auth:web')->group(function () {
            Route::name('profile.')->prefix('profile')->group(function () {
                // Route::get('/', [ProfileController::class, 'edit'])->name('edit');
                Route::get('/', [ProfileController::class, 'edit'])->name('edit');
                Route::patch('/', [ProfileController::class, 'update'])->name('update');
                Route::delete('/', [ProfileController::class, 'destroy'])->name('destroy');
                Route::get('/my-courses', [ProfileController::class, 'getMyCourses'])->name('course');
                Route::get('/student-by-course/{slug}', [ProfileController::class, 'getstudentsByCourse'])->name('students.course');
                Route::post('/upload-avatar', [ProfileController::class, 'uploadAvatar'])->name('upload.avatar');
            });
            Route::get('/cart', [CartController::class, 'index'])->name('site.cart');
            Route::get('/get-count-cart', [CartController::class, 'getCountCart'])->name('site.cart.total_count');
            Route::post('/store-cart', [CartController::class, 'store'])->name('site.store.cart');
            Route::post('/update-cart', [CartController::class, 'update'])->name('site.update.cart');
            Route::delete('/clear-cart', [CartController::class, 'clear'])->name('site.clear.cart');
            Route::delete('/destroy-cart/{id}', [CartController::class, 'destroy'])->name('site.delete.from.cart');

            Route::post('/register-course/{id}', [SiteController::class, 'registerCourse'])->name('site.register.course');

            Route::prefix('order')->group(function () {
                Route::get('/', [SiteController::class, 'getOrder'])->name('site.order');
                Route::post('/store', [OrderController::class, 'store'])->name('site.order.store');
            });
        });


        require __DIR__ . '/auth.php';

        Route::name('site.')->group(function () {
            Route::get('/', [SiteController::class, 'index'])->name('home');
            Route::get('/courses-by-category/{slug}', [SiteController::class, 'coursesByCategory'])->name('courses-by-category');
            Route::post('/contact', [SiteController::class, 'contactUs'])->name('contact');
            Route::get('/contact', [SiteController::class, 'getContactUs'])->name('get-contact');
            Route::get('/gualleries', [SiteController::class, 'getGualleries'])->name('gualleries');
            Route::get('/store', [SiteController::class, 'Store'])->name('store');
            Route::get('/store/{slug}', [SiteController::class, 'StoreDetails'])->name('store.details');
            Route::post('search', [SiteController::class, 'search'])->name('store.search');
            Route::post('search-course', [SiteController::class, 'searchCourse'])->name('search.course');
        });
    }
);
